rusty_mos::memory::pmap

Function page_lookup

pub fn page_lookup(
    pgdir: *mut Pde,
    va: usize,
) -> Option<(*mut PageNode, *mut Pte)>
Look up the Page that virtual address va map to. Return the page and the page table entry together if the page is found and is valid.