rusty_mos::memory::pmap

Function pgdir_walk

pub fn pgdir_walk(
    pgdir: *mut Pde,
    va: usize,
    create: bool,
) -> Result<*mut Pte, KError>
Walk the current page table to find the virtual address va’s page table entry (Pte).

If the pte is not found or is invalid, the parameter create determines whether to create a new entry or just return an error.

Return

Return the pte address found with a Ok wrapper or the KError with an Err wrapper if failed.