rusty_mos::memory::pmap

Type Alias PageNode

pub type PageNode = LinkNode<PageData>;
Node in the page list.

Aliased Type

struct PageNode {
    pub next: *mut LinkNode<PageData>,
    pub prev: *mut *mut LinkNode<PageData>,
    pub data: PageData,
}

Fields

next: *mut LinkNode<PageData>

Pointing the next node. If this is the last node, the field will be null.

prev: *mut *mut LinkNode<PageData>

Pointing the previous node’s next field. If this is the first node, the field will point to the head’s head field.

data: PageData

The data stored in the link list, with the type T.