pub fn page_insert(
pgdir: *mut Pde,
va: usize,
asid: u32,
perm: u32,
page: *mut PageNode,
) -> Result<(), KError>Expand description
Map the physical page to the virtual address va. The permission bits
will be set to perm | PTE_C_CACHEABLE | PTE_V.
If there is already a page mapped at va, page_remove will be invoked
to unmap it.